from django.db import models
from django.contrib.contenttypes.models import ContentType as CT
from django.db.models import Avg
import settings
Q = models.Q
default_vtype_pk = getattr(settings,'DEFAULT_VALUATION_TYPE_ID', 1)

class ValuationTypeManager(models.Manager):
    def get_default_type(self, *args, **kwargs):        
        default_vtype = self.get(pk=getattr(settings,
                                            'DEFAULT_VALUATION_TYPE', 1),
                                *args, **kwargs)
        return default_vtype

    def get_type(self, for_vtype=None, *args, **kwargs):
        if for_vtype:            
            vtype=self.get(title=for_vtype, *args, **kwargs)
        else:
            vtype=self.get_default_type(*args, **kwargs)
            
        return vtype

    def get_choice_queryset(self, for_vtype=None, *args, **kwargs):
        
        return self.get_type(for_vtype).valuationchoice_set.filter(*args, **kwargs)

class ValuationManager(models.Manager):
    '''
    Manager for the valuation model. 
    '''

    def filter_by_vtype_title(self, for_vtype=None, *args, **kwargs):
        '''
        Filter the queryset by title of valuation type.
        '''        
        if for_vtype:            
            return self.filter(vtype__title=for_vtype, *args, **kwargs)            
        else:
            return self.filter(vtype__pk=default_vtype_pk, *args,
                               **kwargs)
    
    def create_for_object(self, obj, *args, **kwargs):
        '''
        Create a valuation instance for object
        '''
        content_type, object_pk = CT.objects.get_for_model(obj), obj.pk
        return self.create(content_type=content_type, object_pk=object_pk,
                           *args, **kwargs)

    def filter_for_obj(self, obj, *args, **kwargs):
        '''
        Filter the valuations according to the object.
        '''
        ctype, object_pk = CT.objects.get_for_model(obj), obj.pk        
        return self.filter_by_vtype_title(content_type=ctype,
                                          object_pk=object_pk, *args,
                                          **kwargs)

    def get_by_obj_client(self, request, obj=None, content_type=None,
                          object_pk=None, *args, **kwargs):                    
        '''
        The instance of valuation which matches the provided object
        and client (user/session) info if exists. 
        '''
        is_authenticated = request.user.is_authenticated()        
        q_session = Q(session=request.COOKIES.get('sessionid', ''))
        q_user = Q(user=request.user) if is_authenticated else Q()
        if obj:
            valuations_for_obj = self.filter_for_obj(obj, *args, **kwargs)
        else:
            #Mostly used in post requests
            valuations_for_obj = self.filter(
                                 content_type=content_type,
                                 object_pk=object_pk,
                                 *args, **kwargs
                                 )
        valuations_for_obj_by_client = valuations_for_obj.filter(
                                        q_session|q_user
                                        )        
        if valuations_for_obj_by_client:
            return valuations_for_obj_by_client[0]
        else:
            return None

    def get_average_score(self, obj, *args, **kwargs):
        '''
        The average valuations score for an object
        '''
        return self.filter_for_obj(obj, *args, **kwargs).aggregate(Avg('choice__value'))['choice__value__avg']
        
    def get_count_for_object(self, obj, *args, **kwargs):
        '''
        The number of valuations for the object.
        '''
        return self.get_for_object(obj, *args, **kwargs).count()

    def get_full_status(self, obj, *args, **kwargs):
        '''
        Get the details about the score count corresponding to each choice
        for the object. Currently template based.
        '''
        valuations = self.filter_for_obj(obj, *args, **kwargs)
        return valuations
    
    def get_choice_count(self, obj, choice, *args, **kwargs):
        '''
        Get the score count for an object for a perticular choice.
        '''
        return self.filter_for_obj(obj, choice__name=choice, *args, **kwargs).count()



from django.test.client import Client
from django.contrib.auth.models import User, AnonymousUser
from django.contrib.sessions.backends.db import SessionStore
from django.http import HttpRequest
from django.test import TestCase
from django.contrib.contenttypes.models import ContentType as CT
from main.models import *
from valuate.models import *
#from valuate.forms import *

ANONYMOUS = False

##CREATING INITIAL OBJECTS
#Used get_or_create to prevent duplicaion as a serialized database dump is present

if ANONYMOUS:
    user = AnonymousUser()
else:
    user = User.objects.get_or_create(username='testuser', email='test@test.com')[0]

request = HttpRequest()
request.user = user
request.session = SessionStore()
request.session.save()
request.COOKIES['sessionid']=request.session.session_key

class ModelTests(TestCase):
    def setUp(self):
        Post.objects.get_or_create(title='Test')[0]
        self.post = Post.objects.get_or_create(title='Test Post')[0]
        vtype = ValuationType.objects.create(title='default')
        self.choice_1 = ValuationChoice.objects.create(name='low',
                                                       value=1,
                                                       vtype=vtype)
        self.choice_2 = ValuationChoice.objects.create(name='medium',
                                                       value=2,
                                                       vtype=vtype)
        self.choice_3 = ValuationChoice.objects.create(name='high',
                                                       value=3,
                                                       vtype=vtype)
        like_type = ValuationType.objects.create(title='like-dislike')
        self.like = ValuationChoice.objects.create(name='like',
                                                       value=1,
                                                       vtype=vtype)
        self.dislike = ValuationChoice.objects.create(name='dislike',
                                                       value=0,
                                                       vtype=vtype)        
        
    def test_create(self):        
        field_dict = {
                      'content_type':CT.objects.get_for_model(self.post),
                      'object_pk': self.post.pk,
                      'choice':self.choice_2,
                      }
        valuation = Valuation(**field_dict)
        valuation.save(request=request)
        self.failUnlessEqual(valuation.id, 1)        
        self.failUnlessEqual(valuation.user, request.user)        

class FormTests(TestCase):
    pass

__test__ = {
}



from django.contrib import admin
from valuate.models import Valuation, ValuationType, ValuationChoice

class ValuationChoiceInline(admin.TabularInline):
    model = ValuationChoice
    extra = 3
	
class ValuationTypeAdmin(admin.ModelAdmin):
    list_display=('title',)
    inlines = [ValuationChoiceInline]

class ValuationAdmin(admin.ModelAdmin):    
    list_display = ('choice', 'vtype', 'content_object', 'content_type', 'submit_date', 'user', 'session')
    list_filter = ['vtype', 'choice', 'content_type', 'submit_date']
    search_fields = ['user__username', 'user__email', 'content_type__app_label', 'ip_address']
    date_hierarchy = 'submit_date'    

admin.site.register(ValuationType, ValuationTypeAdmin)
admin.site.register(Valuation, ValuationAdmin)




from django import template
from django.contrib.contenttypes.models import ContentType as CT
from django.core.urlresolvers import reverse
from valuate.models import Valuation, ValuationType as VT
from valuate.forms import ValuationForm
from valuate.management import valuation_settings as vs
register = template.Library()
VOs=Valuation.objects
'''
Defines the templatetags for easy plugging of valuations with objects.

TODO:
 - Better template Nodes based and more interactive templatetags like
   django comments framework tags. 
'''

def get_valuation_ajax_fields(context, obj, as_var, for_vtype=None):
    '''
    Adds the fields as dictionary required for an ajax post request to
    the context with variable name `as_var` provided as a string.
    Variables available:
    For post request: 'content_type','object_pk', 'value' (to be selected
    by user, can have an initial value if user has already submitted once)
    'choices': dictionary of choices for user to provide the 'value' data.
    'target': target for the request.
    On a successfull request, true will be retuned. 
    If you are not using a popular javascript liberary, pass on a POST
    variable with name `ajax` and a `true` value.
    '''
    request = context['request']
    vtype = VT.objects.get_type(for_vtype)
    choices = VT.objects.get_choice_queryset(for_vtype)
    choice = ''
    target = reverse('valuate-submit')        
    fields = {'chocies': choices, 'target':target,
              'vtype':vtype}
    initial_instance = VOs.get_by_obj_client(request, obj=obj,
                                             for_vtype=for_vtype)
    if initial_instance:
        fields['content_type'] = initial_instance.content_type.id
        fields['object_pk'] = initial_instance.object_pk
        fields['choice'] = initial_instance.choice
    else:    
        fields['content_type'] = CT.objects.get_for_model(obj).id
        fields['object_pk'] = obj.pk
        
    context[as_var]=fields
    return ''

def get_choice_count(context, obj, choice, for_vtype=None):
    '''
    Returns the score count for a perticular choice of an object. Choice
    should be provided with quotes (as string)
    '''
    return VOs.get_choice_count(obj, choice, for_vtype)

def get_valuation_form(context, obj, as_var, for_vtype=None, request=None):
    '''
    Adds the valuation form to the context with variable name as_var
    provided as a string.  
    User `form_name.target` to access the target for the post request.
    '''
    if not request:
        request = context['request']
    form = ValuationForm(request, obj = obj, for_vtype=for_vtype)
    form.fields['choice'].queryset=VT.objects.get_choice_queryset(for_vtype)
    context[as_var]=form
    return ''

def get_valuation_score(context, obj, for_vtype=None):
    '''
    Returns the average score of the object according to the valuations.
    '''
    return VOs.get_average_score(obj, for_vtype)    

def render_valuation_form(context, obj, for_vtype=None, request=None):
    '''
    Renders the valuation form for the object.
    Override template: 'valuate/form.html' for modifying the look.
    '''
    if not request:
        request = context['request']    
    form = ValuationForm(request, obj = obj, for_vtype=for_vtype)    
    form.fields['choice'].queryset=VT.objects.get_choice_queryset(for_vtype)
    return {'form':form}

def render_valuation_status(context, obj, for_vtype=None):
    '''
    Renders the status according to the score of various choices.
    Override template: 'valuate/status.html' for modifying the look.
    '''
    return {'status':VOs.get_full_status(obj, for_vtype)}

register.simple_tag(takes_context=True)(get_valuation_ajax_fields)
register.simple_tag(takes_context=True)(get_choice_count)
register.simple_tag(takes_context=True)(get_valuation_form)
register.simple_tag(takes_context=True)(get_valuation_score)
register.inclusion_tag('valuate/form.html', takes_context=True)(render_valuation_form)
register.inclusion_tag('valuate/status.html', takes_context=True)(render_valuation_status)



from django import forms
from django.db.models import Q
from django.contrib.contenttypes.models import ContentType as CT
from valuate.models import Valuation as V, ValuationType as VT, ValuationChoice as VC

class ValuationForm(forms.ModelForm):
    '''
    The form for valuation model. Exclusively requires the `request`
    context for checking previous object instances according to the
    `current session` or `user` and also passing these variables to
    the model save method while saving the form.
    '''

    def __init__(self, request, data=None, initial={}, obj=None,
                 instance=None, for_vtype=None, *args, **kwargs):
        '''
        Fills `content_type` and `object_pk` according to object and
        processes `request` data
        '''                    
        self.request = self.process_request(request)
        if obj:
            vtype = VT.objects.get_type(for_vtype)
            ctype = CT.objects.get_for_model(obj)
            initial['content_type'] = ctype
            initial['object_pk'] = obj.pk
            initial['vtype'] = vtype
            instance = self.get_instance(request, obj=obj,
                                         for_vtype=for_vtype)            
            
        if request.POST:            
            instance = self.get_instance_by_post_data(request)            
            data = request.POST
        super(ValuationForm, self).__init__(data=data,
                                            initial=initial,
                                            instance=instance,
                                            *args, **kwargs)
    
    content_type= forms.ModelChoiceField(queryset=CT.objects.all(),
                                         widget=forms.HiddenInput)
    object_pk   = forms.CharField(widget=forms.HiddenInput)
    vtype=      forms.ModelChoiceField(queryset=VT.objects.all(),
                                         widget=forms.HiddenInput)

    def clear(self):
        '''
        Clear the instance if an invalid form with instance is submitted. 
        '''
        self.instance.delete()
        try:
            self.instance.delete()
        except AssertionError:
            pass

    def get_id(self):
        '''
        Returns the id for the html form.
        '''
        ctype = self.data.get('content_type', self.initial.get('content_type','').id)
        object_pk = self.data.get('object_pk', self.initial.get('object_pk',''))
        return "valuate_%s_%s" %(ctype, object_pk)
    
    def get_instance(self, request, *args, **kwargs):
        '''
        Returns instance according to the object and request (user,
        session). Needs either object or content_type, object_pk as
        arguments as does `get_by_obj_client`
        '''
        instance = V.objects.get_by_obj_client(request,
                                               *args, **kwargs)        
        return  instance

    def get_instance_by_post_data(self, request, *args, **kwargs):
        '''
        Returns instance according to the post data from request        
        '''
        vtype=request.POST['vtype']
        instance = self.get_instance(request,
                             content_type=request.POST['content_type'],
                             object_pk=request.POST['object_pk'],
                             vtype=request.POST['vtype'],
                             *args, **kwargs)
        return instance

    def process_request(self,request):
        '''
        Prcesses the request to ensure if the session cookie is set.
        TODO: Need to find a better alternative.
        '''
        if request.session.test_cookie_worked():
            request.session.delete_test_cookie()
        if not request.COOKIES.get('sessionid', None):
            request.session.set_test_cookie()                        
        return request
    
    def save(self, *args, **kwargs):
        '''
        Saves the model with the request variable. 
        '''        
        valuation = super(ValuationForm, self).save(commit=False,
                                                    *args, **kwargs)
        valuation.save(self.request)        
        return valuation
    
    class Meta:
        model = V
        fields = ('content_type', 'object_pk', 'choice')



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'ValuationType'
        db.create_table('valuate_valuationtype', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=50)),
        ))
        db.send_create_signal('valuate', ['ValuationType'])

        # Adding model 'ValuationChoice'
        db.create_table('valuate_valuationchoice', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=50)),
            ('value', self.gf('django.db.models.fields.IntegerField')()),
            ('vtype', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['valuate.ValuationType'])),
        ))
        db.send_create_signal('valuate', ['ValuationChoice'])

        # Adding model 'Valuation'
        db.create_table('valuate_valuation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(related_name='content_type_set_for_valuation', to=orm['contenttypes.ContentType'])),
            ('object_pk', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='valuation', null=True, to=orm['auth.User'])),
            ('session', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('vtype', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['valuate.ValuationType'])),
            ('choice', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['valuate.ValuationChoice'])),
            ('ip_address', self.gf('django.db.models.fields.IPAddressField')(max_length=15, null=True, blank=True)),
            ('site', self.gf('django.db.models.fields.related.ForeignKey')(default=1, to=orm['sites.Site'])),
            ('submit_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal('valuate', ['Valuation'])


    def backwards(self, orm):
        
        # Deleting model 'ValuationType'
        db.delete_table('valuate_valuationtype')

        # Deleting model 'ValuationChoice'
        db.delete_table('valuate_valuationchoice')

        # Deleting model 'Valuation'
        db.delete_table('valuate_valuation')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'valuate.valuation': {
            'Meta': {'object_name': 'Valuation'},
            'choice': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['valuate.ValuationChoice']"}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'content_type_set_for_valuation'", 'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'ip_address': ('django.db.models.fields.IPAddressField', [], {'max_length': '15', 'null': 'True', 'blank': 'True'}),
            'object_pk': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'session': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'site': ('django.db.models.fields.related.ForeignKey', [], {'default': '1', 'to': "orm['sites.Site']"}),
            'submit_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'valuation'", 'null': 'True', 'to': "orm['auth.User']"}),
            'vtype': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['valuate.ValuationType']"})
        },
        'valuate.valuationchoice': {
            'Meta': {'object_name': 'ValuationChoice'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'value': ('django.db.models.fields.IntegerField', [], {}),
            'vtype': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['valuate.ValuationType']"})
        },
        'valuate.valuationtype': {
            'Meta': {'object_name': 'ValuationType'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['valuate']



from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.sites.models import Site
from django.contrib.contenttypes import generic
from django.contrib.contenttypes.models import ContentType as CT
from django.core import urlresolvers
from django.contrib.auth.models import User
from valuate.managers import ValuationManager, ValuationTypeManager

import settings

class ValuationType(models.Model):
    title = models.CharField(_('title'), max_length=50)

    objects = ValuationTypeManager()

    def __unicode__(self):
        return self.title.title()

class ValuationChoice(models.Model):
    name = models.CharField(_('choice'), max_length=50)
    value = models.IntegerField(_('value'))
    vtype = models.ForeignKey(ValuationType,
                              verbose_name=_('valuation type'))

    def __unicode__(self):
        return self.name.title()

class Valuation(models.Model):
    '''
    The valuation model.
    '''           
    content_type = models.ForeignKey(CT, verbose_name=_('content type'),
                                     related_name="content_type_set_for_%(class)s")
    object_pk   = models.CharField(_('object ID'), max_length=200)
    content_object = generic.GenericForeignKey("content_type",
                                               "object_pk")
    user        = models.ForeignKey(User, verbose_name=_('user'),
                                   blank=True,
                                   null=True,
                                   related_name="%(class)s")
    session     = models.CharField(_('session'), max_length = 200)
    vtype       = models.ForeignKey(ValuationType,
                                    verbose_name=_('type'))
    choice      = models.ForeignKey(ValuationChoice,
                                    verbose_name=_('choice'))
    ip_address  = models.IPAddressField(_('IP address'),
                                       blank=True,
                                       null=True)
    site        = models.ForeignKey(Site, verbose_name=_('site'),
                                   default = settings.SITE_ID)
    submit_date = models.DateTimeField(_('date/time submitted'),
                                       auto_now_add=True)    
    objects = ValuationManager()        
    def __unicode__(self):
        return '%s: "%s", %s: "%s"' %(unicode(self.content_type).title(),
                                      self.content_object,
                                      self.choice.vtype,
                                      self.choice)

    def get_absoulte_url(self):
        try:
            content_object_url = self.content_object.get_absoulte_url()
        except:
            content_object_url = None
            
        if content_object_url:            
            return content_object_url
        else:
            return '/'
            

    def save(self, request=None, *args, **kwargs):
        '''
        Save method overriden if `request` var is supplied.    
        '''
        self.vtype = self.choice.vtype
        if request:                                                
            sessionid = request.session.session_key
            if sessionid:
                self.ip_address = request.META.get('REMOTE_ADDR', '')
                self.session = sessionid
                if request.user.is_authenticated():
                    self.user = request.user            
                return super(Valuation, self).save(*args, **kwargs)
        else:
            return super(Valuation, self).save(*args, **kwargs)
   
    class Meta:
        pass
        #Prevenet multiple submissions for same client-object pair. 
        unique_together = (('vtype', 'user', 'content_type', 'object_pk'),
                           ('vtype', 'session', 'content_type', 'object_pk'))



from django.conf.urls.defaults import patterns, url
import django.views.generic as gen_views
from main.models import *

urlpatterns = patterns('',
    url(r'^submit/$', 'valuate.views.submit', name = 'valuate-submit'),    
)



#!/usr/bin/env python
try:
    from setuptools import setup
except:
    from distutils.core import setup


from setuptools import find_packages

setup(name='django-valuate',
      version='1.0-beta-1',
      description='Easy plugging of user evaluation system to any django object.',
      long_description=open('README').read(),
      author='Rohan Jain',
      author_email='dcrodjer@gmail.com',
      url='http://code.google.com/p/django-valuate/',
      packages=['valuate'],
      include_package_data=True,
      license="BSD",
      platforms=["all"],
      zip_safe = False
     )



from django.http import HttpResponse, HttpResponseRedirect
from django.template.loader import render_to_string
from django.utils import simplejson
from django.views.decorators.csrf import csrf_protect
from django.views.decorators.http import require_POST
from django.contrib.contenttypes.models import ContentType as CT
from valuate.forms import ValuationForm

@csrf_protect
@require_POST
def submit(request):
    '''
    The submissions of valuation forms will be handled here.
    Ajax supported untested.
    '''
    form = ValuationForm(request)    
    success = False        
    if form.is_valid():        
        valuation = form.save()
        success = True
        redirect = request.REQUEST.get('next',
                                       request.META.get('HTTP_REFERER',
                                                        valuation.get_absoulte_url()))        
    else:        
        form.clear()
        redirect = '/'
    if not request.is_ajax() or request.POST.get('ajax', False):
        return HttpResponseRedirect(redirect)
    else:
        return HttpResponse(simplejson.dumps(success), mimetype='application/javascript')
